# libpythonpro
Módulo para exemplificar construção de projetos python do projeto pytools

Nesse curso é ensinado como contribuir com projetos de código aberto

link [goole](https://goole.com)

[![Python 3](https://pyup.io/repos/github/aislansantos/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/aislansantos/libpythonpro/)

Devido algumas insconsistencias no Travis CI, sistema agora esta fazneodo o
processo de entrega continua pelo Github Actions

suportada versão 3 de python.

Criado um novo pull request ...

Para instalar:


>Comandos no console:
> 
>>python3 -m venv .venv
>
>>source .venv/bin/activate
> 
>>pip install -r requirements-dev.txt
> 
Para conferir qualidade do código:

>flake8.


